@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 Computing Research Labs, New Mexico State University
+ * Copyright 2008 Department of Mathematical Sciences, New Mexico State University
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -14,18 +14,11 @@
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
- * THE COMPUTING RESEARCH LAB OR NEW MEXICO STATE UNIVERSITY BE LIABLE FOR ANY
- * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT
- * OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR
- * THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+ * DEPARTMENT OF MATHEMATICAL SCIENCES OR NEW MEXICO STATE UNIVERSITY BE
+ * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
+ * CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+ * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
-#ifndef lint
-#ifdef __GNUC__
-static char rcsid[] __attribute__ ((unused)) = "$Id: otf2bdf.c,v 1.3 2005/11/07 23:35:24 mleisher Exp $";
-#else
-static char rcsid[] = "$Id: otf2bdf.c,v 1.3 2005/11/07 23:35:24 mleisher Exp $";
-#endif
-#endif
 
 #include <stdio.h>
 
@@ -38,7 +31,7 @@ static char rcsid[] = "$Id: otf2bdf.c,v 1.3 2005/11/07 23:35:24 mleisher Exp $";
 
 #include <string.h>
 
-#include <freetype/freetype.h>
+#include <ft2build.h>
 #include FT_GLYPH_H
 #include FT_SFNT_NAMES_H
 #include FT_TRUETYPE_TABLES_H
@@ -520,9 +513,13 @@ print_encoding_table(void)
         for (j = 0; j < 63 && *np != '-'; np++, j++)
           encoding[j] = *np;
         encoding[j] = 0;
+        /*
+         * Typecast the result of 14-strlen(). This returns a size_t on
+         * some platforms and causes a compilation warning.
+         */
         printf("%s%.*s%s%.*s(-pid %hd -eid %hd)\n",
-               platform, 14 - strlen(platform), spaces,
-               encoding, 14 - strlen(encoding), spaces, pid, eid);
+               platform, (int) (14 - strlen(platform)), spaces,
+               encoding, (int) (14 - strlen(encoding)), spaces, pid, eid);
     }
 }
 
@@ -730,7 +727,7 @@ generate_font(FILE *out, char *iname, char *oname)
     FILE *tmp;
     FT_Short x, y, dwidth, swidth;
     FT_Short y_off, x_off;
-    FT_UShort sx, sy, ex, ey, wd, ht;
+    FT_Long sx, sy, ex, ey, wd, ht;
     FT_Long code, idx, ng, aw;
     FT_UShort remapped_code;
     unsigned char *bp;
@@ -901,7 +898,7 @@ generate_font(FILE *out, char *iname, char *oname)
                 (long) remapped_code);
         fprintf(tmp, "SWIDTH %hd 0\n", swidth);
         fprintf(tmp, "DWIDTH %hd 0\n", dwidth);
-        fprintf(tmp, "BBX %hd %hd %hd %hd\n", wd, ht, x_off, y_off);
+        fprintf(tmp, "BBX %ld %ld %hd %hd\n", wd, ht, x_off, y_off);
 
         /*
          * Check for an error return here in case the temporary file system
@@ -912,7 +909,7 @@ generate_font(FILE *out, char *iname, char *oname)
         bp = face->glyph->bitmap.buffer + (sy * face->glyph->bitmap.pitch);
         for (y = 0; eof != EOF && y < ey - sy; y++) {
             for (idx = 0, x = 0; eof != EOF && x < ex - sx; x++) {
-                if (x > sx && (x & 7) == 0) {
+                if (x > 0 && (x & 7) == 0) {
                     /*
                      * Print the next byte.
                      */
